scn: Scaling, centering and normalizing a matrix

Description Usage Arguments Value Examples

View source: R/dpreproc.R

Description

Scales a non-negative numerical matrix by applying the logarithm function and centers and normalizes its data. When applying the logarithm function it adds one to avoid calculating the logarithm of zero.

Usage

1

Arguments

data

non-negative numerical matrix with column names

Value

numerical matrix

Examples

1
2
3
m <- matrix(1:4, nr= 2, nc = 2)
colnames(m)<-c("1", "2")
scn(m)

carmen-maria-hernandez/SuCoNets documentation built on Dec. 19, 2021, 1:53 p.m.