Description Usage Arguments Value Examples
Scales a non-negative numerical matrix by applying the logarithm function and centers and normalizes its data. When applying the logarithm function it adds one to avoid calculating the logarithm of zero.
1 |
data |
non-negative numerical matrix with column names |
numerical matrix
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.